[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[or-cvs] r15687: prepare for more renaming (in puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi: . execute impl)
Author: sebastian
Date: 2008-07-06 08:44:43 -0400 (Sun, 06 Jul 2008)
New Revision: 15687
Modified:
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorMasterFactory.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorSlaveFactory.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/CreateNetwork.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/LocalPuppeTorMaster.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/MasterConnector.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorMaster.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorSlave.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTest.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTestResult.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/RemotePuppeTorMaster.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/TestExecutor.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorMasterProgram.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorSlaveProgram.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImpl.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImplFactory.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImpl.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImplFactory.java
puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/TestExecutorImpl.java
Log:
prepare for more renaming
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorMasterFactory.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorMasterFactory.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorMasterFactory.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -39,21 +39,21 @@
*
* @author Sebastian Hahn
*/
-public abstract class AbstractPuppeTorMasterFactory {
+public abstract class AbstractMasterFactory {
/**
* Hold the concrete RemotePuppeTorFactory that will be used to create the
* implementation classes. Use
- * <code>AbstractPuppeTorMasterFactory.class</code> for locking.
+ * <code>AbstractMasterFactory.class</code> for locking.
*/
- private static AbstractPuppeTorMasterFactory factory;
+ private static AbstractMasterFactory factory;
/**
* @return a new concrete
* <code>AbstractRemotePuppeTorFactory<code>subclass as
* specified by the initialization
*/
- final public synchronized static AbstractPuppeTorMasterFactory getInstance() {
+ final public synchronized static AbstractMasterFactory getInstance() {
return factory;
}
@@ -62,9 +62,9 @@
* save this as the factory if this hasn't been called before.
*/
final public synchronized static void initialize(
- final AbstractPuppeTorMasterFactory factory) {
- if (AbstractPuppeTorMasterFactory.factory == null) {
- AbstractPuppeTorMasterFactory.factory = factory;
+ final AbstractMasterFactory factory) {
+ if (AbstractMasterFactory.factory == null) {
+ AbstractMasterFactory.factory = factory;
}
}
@@ -75,7 +75,7 @@
* Create the server represantation for this connected slave
* @return The new <code>RemotePuppeTor</code> instance
*/
- public abstract PuppeTorMaster createPuppeTorMaster(PuppeTorSlave slave)
+ public abstract Master createPuppeTorMaster(Slave slave)
throws RemoteException;
/**
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorSlaveFactory.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/CreateNetwork.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/CreateNetwork.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -43,7 +43,7 @@
import de.uniba.wiai.lspi.puppetor.ProxyNode;
import de.uniba.wiai.lspi.puppetor.PuppeTorException;
-public class CreateNetwork implements PuppeTorTest {
+public class CreateNetwork implements Test {
private static final long serialVersionUID = 1L;
public Object doJob() throws RemoteException, PuppeTorException {
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/LocalPuppeTorMaster.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/LocalPuppeTorMaster.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/LocalPuppeTorMaster.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -33,16 +33,16 @@
/**
* Represent a connection between the locally running PuppeTor network Master
- * and a slave. This is the master part of the <code>PuppeTorMaster</code>
+ * and a slave. This is the master part of the <code>Master</code>
* interface.
*
* @author Sebastian Hahn
*/
-public interface LocalPuppeTorMaster {
+public interface LocalMaster {
/**
* @return the slave instance this connection refers to.
*/
- public PuppeTorSlave getSlave();
+ public Slave getSlave();
/**
* Register with the TestExecutor
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/MasterConnector.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/MasterConnector.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/MasterConnector.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -52,6 +52,6 @@
* @return The representation of the master
* @throws RemoteException
*/
- public RemotePuppeTorMaster registerClient(final PuppeTorSlave slave)
+ public RemoteMaster registerClient(final Slave slave)
throws RemoteException;
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorMaster.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorMaster.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorMaster.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -31,7 +31,6 @@
*/
package de.uniba.wiai.lspi.puppetor.rmi;
-public interface PuppeTorMaster /*extends LocalPuppeTorMaster,
-RemotePuppeTorMaster*/ {
+public interface Master {
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorSlave.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorSlave.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorSlave.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -36,14 +36,14 @@
import java.util.Set;
/**
- * A <code>PuppeTorSlave</code> represents a slave instance ready for tests.
+ * A <code>Slave</code> represents a slave instance ready for tests.
* It carries information about the testing capabilities of a given slave. A
* slave may not provide information except for its name, which is always
* mandatory. The slave will not be used for non-client traffic, though.
*
* @author Sebastian Hahn
*/
-public interface PuppeTorSlave extends Serializable {
+public interface Slave extends Serializable {
public enum OS {
UNDEFINED, LINUX_I86_32, LINUX_I86_64, MAC_OSX_PPC, MAC_OSX_I86,
@@ -57,7 +57,7 @@
/**
* @return the slave's operating system as defined in
- * <code>PuppeTorSlave.OS</code>.
+ * <code>Slave.OS</code>.
*/
public OS getOS();
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTest.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTest.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTest.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -37,14 +37,14 @@
import de.uniba.wiai.lspi.puppetor.PuppeTorException;
/**
- * <code>PuppeTorTest</code> describes a test and the kind of slave it can run
+ * <code>Test</code> describes a test and the kind of slave it can run
* on, as well as other network settings that are required for the test to work.
* A test should be able to tell whether it was successfully run or not when
- * passed a PuppeTorTestResult.
+ * passed a TestResult.
*
* @author Sebastian Hahn
*/
-public interface PuppeTorTest extends Serializable {
+public interface Test extends Serializable {
/**
* XXX this goes away. I just put it in to see whether a remote test would
* actually execut on a slave.
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTestResult.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTestResult.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/PuppeTorTestResult.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -34,9 +34,9 @@
import java.io.Serializable;
/**
- * XXX unused for now. this will hold the result of a /<code>PuppeTorTest</code>
+ * XXX unused for now. this will hold the result of a /<code>Test</code>
* -SH
*/
-public interface PuppeTorTestResult extends Serializable {
- public PuppeTorTest getJob();
+public interface TestResult extends Serializable {
+ public Test getJob();
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/RemotePuppeTorMaster.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/RemotePuppeTorMaster.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/RemotePuppeTorMaster.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -39,7 +39,7 @@
* interaction between the interconnected master and its slave instances. It is
* published by the master's instance, and represents the view of the master a
* slave has. It provides ways for the slave to register a
- * <code>PuppeTorSlave</code> to provide information about its capabilities,
+ * <code>Slave</code> to provide information about its capabilities,
* as well as a way for the slave to poll the master for new work and then
* report back results. XXX We will need a way to allow the master to access
* this, as well as a way for clients with open ports to register for callback
@@ -47,7 +47,7 @@
*
* @author Sebastian Hahn
*/
-public interface RemotePuppeTorMaster extends Remote {
+public interface RemoteMaster extends Remote {
/**
* Slaves that must poll because they are not reachable can use this method
@@ -56,7 +56,7 @@
* @throws RemoteException
* RMI...
*/
- public PuppeTorTest getNewJob() throws RemoteException;
+ public Test getNewJob() throws RemoteException;
/**
* XXX We want the slaves to report back when they have an update for the
@@ -65,7 +65,7 @@
* @param jobResult
* @throws RemoteException
*
- * public void reportResults(PuppeTorTestResult testResult) throws
+ * public void reportResults(TestResult testResult) throws
* RemoteException;
*/
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/TestExecutor.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/TestExecutor.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/TestExecutor.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -50,7 +50,7 @@
* Accept all submitted tests even though some may not be executable at the
* moment of submission.
*/
- public void registerTest(PuppeTorTest test);
+ public void registerTest(Test test);
/**
* Start executing tests. Callers should make sure that the PuppeTor network
@@ -62,28 +62,28 @@
* Return a Map of the nodes that have been run successfully along with the
* results of the tests.
*/
- public ConcurrentMap<PuppeTorTest, PuppeTorTestResult> getSuccessfulTests();
+ public ConcurrentMap<Test, TestResult> getSuccessfulTests();
/**
* Return a Map of the nodes that have been run but didn't complete
* successfully along with the results of the tests.
*/
- public ConcurrentMap<PuppeTorTest, PuppeTorTestResult> getFailedTests();
+ public ConcurrentMap<Test, TestResult> getFailedTests();
/**
* Return all tests that could not be executed because the PuppeTorNetwork
* could not match a test's preconditions.
*/
- public Set<PuppeTorTest> getNotRunTests();
+ public Set<Test> getNotRunTests();
/**
* Register a newly connected PuppeTor slave via its
- * <code>LocalPuppeTorMaster</code> connection object.
+ * <code>LocalMaster</code> connection object.
*/
- public void registerLocalMaster(LocalPuppeTorMaster master);
+ public void registerLocalMaster(LocalMaster master);
/**
* Unregister a PuppeTor slave. Called when a slave disconnects.
*/
- public void unregisterLocalMaster(LocalPuppeTorMaster master);
+ public void unregisterLocalMaster(LocalMaster master);
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorMasterProgram.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorMasterProgram.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorMasterProgram.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -39,13 +39,13 @@
import javax.rmi.ssl.SslRMIClientSocketFactory;
import javax.rmi.ssl.SslRMIServerSocketFactory;
-import de.uniba.wiai.lspi.puppetor.rmi.AbstractPuppeTorMasterFactory;
-import de.uniba.wiai.lspi.puppetor.rmi.LocalPuppeTorMaster;
+import de.uniba.wiai.lspi.puppetor.rmi.AbstractMasterFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.LocalMaster;
import de.uniba.wiai.lspi.puppetor.rmi.MasterConnector;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave;
-import de.uniba.wiai.lspi.puppetor.rmi.RemotePuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.impl.PuppeTorMasterImplFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.Master;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave;
+import de.uniba.wiai.lspi.puppetor.rmi.RemoteMaster;
+import de.uniba.wiai.lspi.puppetor.rmi.impl.MasterImplFactory;
/**
* The <code>PuppeTorMasterProgram</code> contains the main method for the
@@ -106,8 +106,8 @@
// Tell the RMI system the location of the master
System.setProperty("java.rmi.server.hostname", serveraddress);
// Set up the factories we want to use
- AbstractPuppeTorMasterFactory
- .initialize(new PuppeTorMasterImplFactory());
+ AbstractMasterFactory
+ .initialize(new MasterImplFactory());
try {
master = new InnerMasterConnector();
@@ -158,13 +158,13 @@
*/
public InnerMasterConnector() throws RemoteException {}
- public RemotePuppeTorMaster registerClient(final PuppeTorSlave slave)
+ public RemoteMaster registerClient(final Slave slave)
throws RemoteException {
- final AbstractPuppeTorMasterFactory fact =
- AbstractPuppeTorMasterFactory.getInstance();
- final PuppeTorMaster master = fact.createPuppeTorMaster(slave);
- ((LocalPuppeTorMaster)master).registerWithTestExecutor();
- return (RemotePuppeTorMaster)master;
+ final AbstractMasterFactory fact =
+ AbstractMasterFactory.getInstance();
+ final Master master = fact.createPuppeTorMaster(slave);
+ ((LocalMaster)master).registerWithTestExecutor();
+ return (RemoteMaster)master;
}
}
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorSlaveProgram.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorSlaveProgram.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/execute/PuppeTorSlaveProgram.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -42,12 +42,12 @@
import javax.rmi.ssl.SslRMIClientSocketFactory;
import de.uniba.wiai.lspi.puppetor.PuppeTorException;
-import de.uniba.wiai.lspi.puppetor.rmi.AbstractPuppeTorSlaveFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.AbstractSlaveFactory;
import de.uniba.wiai.lspi.puppetor.rmi.MasterConnector;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorTest;
-import de.uniba.wiai.lspi.puppetor.rmi.RemotePuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.impl.PuppeTorSlaveImplFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave;
+import de.uniba.wiai.lspi.puppetor.rmi.Test;
+import de.uniba.wiai.lspi.puppetor.rmi.RemoteMaster;
+import de.uniba.wiai.lspi.puppetor.rmi.impl.SlaveImplFactory;
/**
* The <code>PuppeTorSlaveProgram</code> contains the main method for the
@@ -65,7 +65,7 @@
* The <code>RemotePuppeTor</code> object that is exported by the server.
* This variable may be written to only from the main thread.
*/
- volatile private RemotePuppeTorMaster master;
+ volatile private RemoteMaster master;
/**
* The port the master server is supposed to listen on. This port must not
@@ -90,7 +90,7 @@
/**
* A representation of this slave node to be sent to the master.
*/
- final private PuppeTorSlave slave;
+ final private Slave slave;
/**
* Slave application entry point
@@ -111,7 +111,7 @@
// XXX How about we spawn a thread here that polls for new work and puts
// it in a nice little queue that some worker threads use...
try {
- final PuppeTorTest job = slave.master.getNewJob();
+ final Test job = slave.master.getNewJob();
if (job != null) {
final Object res = job.doJob();
}
@@ -143,9 +143,9 @@
*/
System.setProperty("javax.net.ssl.trustStore", "res/truststore");
// Set up the factories we want to use
- AbstractPuppeTorSlaveFactory.initialize(new PuppeTorSlaveImplFactory());
- final AbstractPuppeTorSlaveFactory fac =
- AbstractPuppeTorSlaveFactory.getInstance();
+ AbstractSlaveFactory.initialize(new SlaveImplFactory());
+ final AbstractSlaveFactory fac =
+ AbstractSlaveFactory.getInstance();
/*
* Create a new slave with the properties that are relevant for the
@@ -158,7 +158,7 @@
final Set<Integer> availableRevisions =
new CopyOnWriteArraySet<Integer>();
slave =
- fac.createPuppeTorSlave(slaveName, PuppeTorSlave.OS.UNDEFINED,
+ fac.createPuppeTorSlave(slaveName, Slave.OS.UNDEFINED,
"127.0.0.1", ports, availableRevisions);
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImpl.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImpl.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImpl.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -35,13 +35,13 @@
import java.rmi.server.UnicastRemoteObject;
import java.rmi.server.Unreferenced;
-import de.uniba.wiai.lspi.puppetor.rmi.AbstractPuppeTorMasterFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.AbstractMasterFactory;
import de.uniba.wiai.lspi.puppetor.rmi.CreateNetwork;
-import de.uniba.wiai.lspi.puppetor.rmi.LocalPuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorTest;
-import de.uniba.wiai.lspi.puppetor.rmi.RemotePuppeTorMaster;
+import de.uniba.wiai.lspi.puppetor.rmi.LocalMaster;
+import de.uniba.wiai.lspi.puppetor.rmi.Master;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave;
+import de.uniba.wiai.lspi.puppetor.rmi.Test;
+import de.uniba.wiai.lspi.puppetor.rmi.RemoteMaster;
/**
* Represent the master at the slave, and give the master a way to interact with
@@ -49,8 +49,8 @@
*
* @author Sebastian Hahn
*/
-public class PuppeTorMasterImpl extends UnicastRemoteObject implements
- LocalPuppeTorMaster, RemotePuppeTorMaster, PuppeTorMaster, Unreferenced {
+public class MasterImpl extends UnicastRemoteObject implements
+ LocalMaster, RemoteMaster, Master, Unreferenced {
/**
* Required for serialization. Needs to change for new released versions.
@@ -60,14 +60,14 @@
/**
* Store the reference to the connected slave
*/
- private final PuppeTorSlave slave;
+ private final Slave slave;
- public PuppeTorSlave getSlave() {
+ public Slave getSlave() {
return slave;
}
public void registerWithTestExecutor() {
- AbstractPuppeTorMasterFactory.getInstance().createTestExecutor()
+ AbstractMasterFactory.getInstance().createTestExecutor()
.registerLocalMaster(this);
}
@@ -77,7 +77,7 @@
* @throws RemoteException
* RMI
*/
- public PuppeTorMasterImpl(final PuppeTorSlave slave) throws RemoteException {
+ public MasterImpl(final Slave slave) throws RemoteException {
if (slave.getName() == null) {
throw new NullPointerException("The slave's name must not be null!");
}
@@ -88,12 +88,12 @@
* XXX Currently, there is no logic to give back useful tasks, but if the
* client is known, a new <code>CreateNetwork</code> test is submitted.-SH
*/
- public PuppeTorTest getNewJob() throws RemoteException {
+ public Test getNewJob() throws RemoteException {
return new CreateNetwork();
}
// public void repoprtResults(final String slaveName,
- // final PuppeTorTestResult jobResult) throws RemoteException {
+ // final TestResult jobResult) throws RemoteException {
// XXX We want to let the server know that the client did some work and
// how it turned out to be. -SH
// }
@@ -105,7 +105,7 @@
* do that when there are the queues that I mentioned.-SH
*/
public void unreferenced() {
- AbstractPuppeTorMasterFactory.getInstance().createTestExecutor()
+ AbstractMasterFactory.getInstance().createTestExecutor()
.unregisterLocalMaster(this);
}
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImplFactory.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImplFactory.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorMasterImplFactory.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -32,9 +32,9 @@
package de.uniba.wiai.lspi.puppetor.rmi.impl;
import java.rmi.RemoteException;
-import de.uniba.wiai.lspi.puppetor.rmi.AbstractPuppeTorMasterFactory;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave;
+import de.uniba.wiai.lspi.puppetor.rmi.AbstractMasterFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.Master;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave;
import de.uniba.wiai.lspi.puppetor.rmi.TestExecutor;
/**
@@ -42,12 +42,12 @@
*
* @author Sebastian Hahn
*/
-public class PuppeTorMasterImplFactory extends AbstractPuppeTorMasterFactory {
+public class MasterImplFactory extends AbstractMasterFactory {
@Override
- public PuppeTorMaster createPuppeTorMaster(final PuppeTorSlave slave)
+ public Master createPuppeTorMaster(final Slave slave)
throws RemoteException {
- return new PuppeTorMasterImpl(slave);
+ return new MasterImpl(slave);
}
@Override
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImpl.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImpl.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImpl.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -37,7 +37,7 @@
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave;
/**
* Describe a client including its capabilities and network location to the
@@ -47,7 +47,7 @@
*
* @author Sebastian Hahn
*/
-public final class PuppeTorSlaveImpl implements PuppeTorSlave {
+public final class SlaveImpl implements Slave {
/**
* Required for serialization. Needs to change for new released versions.
@@ -65,7 +65,7 @@
protected final InetAddress ip;
/**
- * The operating system of the slave. See <code>PuppeTorSlave.OS</code>.
+ * The operating system of the slave. See <code>Slave.OS</code>.
*/
protected final OS os;
@@ -82,7 +82,7 @@
protected final Set<Integer> availableRevisions;
/**
- * Create a new <code>PuppeTorSlave</code> with the metrics we currently
+ * Create a new <code>Slave</code> with the metrics we currently
* use, meaning it's operating system, it's IP, and the ports it can open.
* We may in the future include other things like Tor executable version
* numbers and the ability to run certain extra scripts.
@@ -100,7 +100,7 @@
* @throws NullPointerException
* if the slavename is null
*/
- public PuppeTorSlaveImpl(final String slaveName, final OS os,
+ public SlaveImpl(final String slaveName, final OS os,
final String ip, final Set<Integer> ports,
final Set<Integer> availableRevisions) throws NullPointerException {
if (slaveName == null) {
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImplFactory.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImplFactory.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/PuppeTorSlaveImplFactory.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -33,26 +33,26 @@
import java.util.Set;
-import de.uniba.wiai.lspi.puppetor.rmi.AbstractPuppeTorSlaveFactory;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave.OS;
+import de.uniba.wiai.lspi.puppetor.rmi.AbstractSlaveFactory;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave.OS;
/**
* Create <code>RemotePuppeTorImpl</code> instances
*
* @author Sebastian Hahn
*/
-public class PuppeTorSlaveImplFactory extends AbstractPuppeTorSlaveFactory {
+public class SlaveImplFactory extends AbstractSlaveFactory {
/**
* @return a new <code>RemotePuppeTorImpl</code> instance.
*/
@Override
- public PuppeTorSlave createPuppeTorSlave(final String slaveName,
+ public Slave createPuppeTorSlave(final String slaveName,
final OS os, final String ip, final Set<Integer> ports,
final Set<Integer> availableRevisions) throws NullPointerException {
System.out.println(slaveName);
- return new PuppeTorSlaveImpl(slaveName, os, ip, ports,
+ return new SlaveImpl(slaveName, os, ip, ports,
availableRevisions);
}
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/TestExecutorImpl.java
===================================================================
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/TestExecutorImpl.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/impl/TestExecutorImpl.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -35,9 +35,9 @@
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
-import de.uniba.wiai.lspi.puppetor.rmi.LocalPuppeTorMaster;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorTest;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorTestResult;
+import de.uniba.wiai.lspi.puppetor.rmi.LocalMaster;
+import de.uniba.wiai.lspi.puppetor.rmi.Test;
+import de.uniba.wiai.lspi.puppetor.rmi.TestResult;
import de.uniba.wiai.lspi.puppetor.rmi.TestExecutor;
/**
@@ -54,8 +54,8 @@
* Store all local representations of connections to slaves. Use the slave's
* name as key.
*/
- private static final ConcurrentMap<String, LocalPuppeTorMaster> masters =
- new ConcurrentHashMap<String, LocalPuppeTorMaster>();
+ private static final ConcurrentMap<String, LocalMaster> masters =
+ new ConcurrentHashMap<String, LocalMaster>();
/**
* Singleton
@@ -67,7 +67,7 @@
return instance;
}
- public void registerLocalMaster(final LocalPuppeTorMaster master) {
+ public void registerLocalMaster(final LocalMaster master) {
System.out.println("register slave " + master.getSlave().getName());
if (null != masters.putIfAbsent(master.getSlave().getName(), master)) {
throw new IllegalArgumentException(master.getSlave().getName()
@@ -76,7 +76,7 @@
}
- public void unregisterLocalMaster(final LocalPuppeTorMaster master) {
+ public void unregisterLocalMaster(final LocalMaster master) {
// XXX Don't forget to mark all tests as failed that depended on this
// slave-SH
System.out.println("unregister slave " + master.getSlave().getName());
@@ -95,22 +95,22 @@
}
- public ConcurrentMap<PuppeTorTest, PuppeTorTestResult> getFailedTests() {
+ public ConcurrentMap<Test, TestResult> getFailedTests() {
// TODO Auto-generated method stub
return null;
}
- public Set<PuppeTorTest> getNotRunTests() {
+ public Set<Test> getNotRunTests() {
// TODO Auto-generated method stub
return null;
}
- public ConcurrentMap<PuppeTorTest, PuppeTorTestResult> getSuccessfulTests() {
+ public ConcurrentMap<Test, TestResult> getSuccessfulTests() {
// TODO Auto-generated method stub
return null;
}
- public void registerTest(final PuppeTorTest test) {
+ public void registerTest(final Test test) {
// TODO Auto-generated method stub
}
--- puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorSlaveFactory.java 2008-07-06 09:18:25 UTC (rev 15686)
+++ puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/AbstractPuppeTorSlaveFactory.java 2008-07-06 12:44:43 UTC (rev 15687)
@@ -33,7 +33,7 @@
import java.util.Set;
-import de.uniba.wiai.lspi.puppetor.rmi.PuppeTorSlave.OS;
+import de.uniba.wiai.lspi.puppetor.rmi.Slave.OS;
/**
* Create a new representation of the server. Initialize this once with a
@@ -42,21 +42,21 @@
*
* @author Sebastian Hahn
*/
-public abstract class AbstractPuppeTorSlaveFactory {
+public abstract class AbstractSlaveFactory {
/**
* Hold the concrete RemotePuppeTorFactory that will be used to create
* <code>PuppeTorSlave</code> instances. Uses
* <code>AbstractPuppeTorSlaveFactory.class</code> for locking.
*/
- private static AbstractPuppeTorSlaveFactory factory;
+ private static AbstractSlaveFactory factory;
/**
* @return a new concrete
- * <code>AbstractPuppeTorSlaveFactory<code>subclass as
+ * <code>AbstractSlaveFactory<code>subclass as
* specified by the initialization
*/
- final public synchronized static AbstractPuppeTorSlaveFactory getInstance() {
+ final public synchronized static AbstractSlaveFactory getInstance() {
return factory;
}
@@ -67,18 +67,18 @@
* about that.-SH
*/
final public synchronized static void initialize(
- final AbstractPuppeTorSlaveFactory factory) {
- if (AbstractPuppeTorSlaveFactory.factory == null) {
- AbstractPuppeTorSlaveFactory.factory = factory;
+ final AbstractSlaveFactory factory) {
+ if (AbstractSlaveFactory.factory == null) {
+ AbstractSlaveFactory.factory = factory;
}
}
/**
- * Override this to create a subclass of <code>PuppeTorSlave</code>
+ * Override this to create a subclass of <code>Slave</code>
*
- * @return The new <code>PuppeTorSlave</code> instance
+ * @return The new <code>Slave</code> instance
*/
- public abstract PuppeTorSlave createPuppeTorSlave(final String slaveName,
+ public abstract Slave createPuppeTorSlave(final String slaveName,
final OS os, final String ip, final Set<Integer> ports,
final Set<Integer> availableRevisions) throws NullPointerException;
}
@@ -42,21 +42,21 @@
/**
* Hold the concrete RemotePuppeTorFactory that will be used to create
- * <code>PuppeTorSlave</code> instances. Uses
- * <code>AbstractPuppeTorSlaveFactory.class</code> for locking.
+ * <code>Slave</code> instances. Uses
+ * <code>AbstractSlaveFactory.class</code> for locking.
*/
Modified: puppetor/branches/gsoc2008/src/de/uniba/wiai/lspi/puppetor/rmi/CreateNetwork.java
===================================================================